# pytel < https://t.me/kastaid >
# Copyright (C) 2023-present kastaid
#
# This file is a part of < https://github.com/kastaid/pytel/ >
# Please read the GNU Affero General Public License in
# < https://github.com/kastaid/pytel/blob/main/LICENSE/ >.

from base64 import b64decode


_c, _g, _l, _d, gsc, gse, _i, cpytl = (
    b64decode("a2FzdGFpZA==").decode(
        "utf-8"
    ),
    b64decode("a2FzdGFvdA==").decode(
        "utf-8"
    ),
    b64decode("QExQTV9MaW51eA==").decode(
        "utf-8"
    ),
    b64decode(
        "QGRpcnR5c291bHZWdg=="
    ).decode("utf-8"),
    b64decode(
        "QUl6YVN5Q3kweHJmOEdOOHB4cjZtRmMwZjhFZC1NUFlNLXlqZEZn"
    ).decode("utf-8"),
    b64decode(
        "NTZjYzA4MDM5M2IwOTRmNTg="
    ).decode("utf-8"),
    b64decode(
        "Z2l0IHJlbW90ZSBzZXQtdXJsIG9yaWdpbiBodHRwczovL2dpdGh1Yi5jb20va2FzdGFpZC9weXRlbC5naXQ="
    ).decode("utf-8"),
    b64decode(
        "QFBZVEVMUHJlbWl1bQ=="
    ).decode("utf-8"),
)

_supersu = (
    1714407386, # ax
    1448477501, # 1st
    1998918024, # evn1
    2003361410, # evn2
    6259202093, # n4us
    6585494291, # citra
)

GCAST_BLACKLIST = (
    -1001699144606,  # @kastaot
    -1001700971911,  # @kastaup
    -1001596433756,  # @MFIChat
    -1001294181499,  # @userbotindo
    -1001387666944,  # @PyrogramChat
    -1001221450384,  # @pyrogramlounge
    -1001109500936,  # @TelethonChat
    -1001235155926,  # @RoseSupportChat
    -1001421589523,  # @tdspya
    -1001360494801,  # @OFIOpenChat
    -1001275084637,  # @OFIChat
    -1001435671639,  # @xfichat
)

GUCAST_BLACKLIST = (
    777000,  # Telegram
    4247000,  # @notoscam
    431415000,  # @BotSupport
    454000,  # @dmcatelegram
)

DEFAULT_SHELL_BLACKLISTED = (
    "rm",
    "-delete",
    "unlink",
    "shred",
    "rsync",
    "sleep",
    "history",
    "dd",
    "chmod",
    "chown",
    "mkfs",
    "mkswap",
    "chroot",
    "fdisk",
    "poweroff",
    "shutdown",
    "reboot",
    "halt",
    "exec",
    "kill",
    "crontab",
    "perl",
    "while",
    ":()",
    "/dev",
    "sudo",
    "dpkg",
    "apt",
    "pkill",
)

_kastaot = (
    -1001699144606,
)

_chpytel = (
    -1001901158945,
)
